@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: ZipHandler.cxx 3239 2015-12-29 19:22:46Z stephena $
+// $Id: ZipHandler.cxx 3308 2016-05-24 16:55:45Z stephena $
 //============================================================================
 
 #include <cctype>
@@ -76,7 +76,7 @@ string ZipHandler::next()
 
       // Ignore zero-length files and '__MACOSX' virtual directories
       valid = header && (header->uncompressed_length > 0) &&
-              !BSPF_startsWithIgnoreCase(header->filename, "__MACOSX");
+              !BSPF::startsWithIgnoreCase(header->filename, "__MACOSX");
     }
     while(!valid && myZip->cd_pos < myZip->ecd.cd_size);
 
@@ -133,11 +133,11 @@ bool ZipHandler::stream_open(const char* filename, fstream** stream,
   }
   else
   {
-    in->exceptions( ios_base::failbit | ios_base::badbit | ios_base::eofbit );
+    in->exceptions( std::ios_base::failbit | std::ios_base::badbit | std::ios_base::eofbit );
     *stream = in;
-    in->seekg(0, ios::end);
+    in->seekg(0, std::ios::end);
     length = in->tellg();
-    in->seekg(0, ios::beg);
+    in->seekg(0, std::ios::beg);
     return true;
   }
 }
@@ -266,9 +266,9 @@ ZipHandler::zip_error ZipHandler::zip_file_open(const char* filename, zip_file**
   while(hasNext())
   {
     const std::string& file = next();
-    if(BSPF_endsWithIgnoreCase(file, ".a26") ||
-       BSPF_endsWithIgnoreCase(file, ".bin") ||
-       BSPF_endsWithIgnoreCase(file, ".rom"))
+    if(BSPF::endsWithIgnoreCase(file, ".a26") ||
+       BSPF::endsWithIgnoreCase(file, ".bin") ||
+       BSPF::endsWithIgnoreCase(file, ".rom"))
       (*zip)->romfiles++;
   }
 
@@ -616,7 +616,7 @@ ZipHandler::zip_error
   {
     // Read in the next chunk of data
     bool success = stream_read(zip->file, zip->buffer, offset,
-                      BSPF_min(input_remaining, (uInt32)sizeof(zip->buffer)),
+                      std::min(input_remaining, (uInt32)sizeof(zip->buffer)),
                       read_length);
     if(!success)
     {
