@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: Debugger.cxx 3244 2015-12-30 19:07:11Z stephena $
+// $Id: Debugger.cxx 3314 2016-08-22 16:53:09Z stephena $
 //============================================================================
 
 #include "bspf.hxx"
@@ -143,10 +143,10 @@ void Debugger::initialize()
 
   // The debugger dialog is resizable, within certain bounds
   // We check those bounds now
-  myWidth  = BSPF_max(myWidth,  uInt32(DebuggerDialog::kSmallFontMinW));
-  myHeight = BSPF_max(myHeight, uInt32(DebuggerDialog::kSmallFontMinH));
-  myWidth  = BSPF_min(myWidth,  uInt32(d.w));
-  myHeight = BSPF_min(myHeight, uInt32(d.h));
+  myWidth  = std::max(myWidth,  uInt32(DebuggerDialog::kSmallFontMinW));
+  myHeight = std::max(myHeight, uInt32(DebuggerDialog::kSmallFontMinH));
+  myWidth  = std::min(myWidth,  uInt32(d.w));
+  myHeight = std::min(myHeight, uInt32(d.h));
 
   myOSystem.settings().setValue("dbg.res", GUI::Size(myWidth, myHeight));
 
@@ -255,7 +255,9 @@ const string Debugger::invIfChanged(int reg, int oldReg)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void Debugger::reset()
 {
+  unlockBankswitchState();
   mySystem.reset();
+  lockBankswitchState();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -576,13 +578,13 @@ string Debugger::builtinHelp() const
     if(len > i_maxlen)  i_maxlen = len;
   }
 
-  buf << setfill(' ') << endl << "Built-in functions:" << endl;
+  buf << std::setfill(' ') << endl << "Built-in functions:" << endl;
   for(int i = 0; builtin_functions[i][0] != 0; ++i)
   {
-    buf << setw(c_maxlen) << left << builtin_functions[i][0]
-        << setw(2) << right << "{"
-        << setw(i_maxlen) << left << builtin_functions[i][1]
-        << setw(4) << "}"
+    buf << std::setw(c_maxlen) << std::left << builtin_functions[i][0]
+        << std::setw(2) << std::right << "{"
+        << std::setw(i_maxlen) << std::left << builtin_functions[i][1]
+        << std::setw(4) << "}"
         << builtin_functions[i][2]
         << endl;
   }
@@ -598,9 +600,9 @@ string Debugger::builtinHelp() const
   buf << endl << "Pseudo-registers:" << endl;
   for(int i = 0; pseudo_registers[i][0] != 0; ++i)
   {
-    buf << setw(c_maxlen) << left << pseudo_registers[i][0]
-        << setw(2) << " "
-        << setw(i_maxlen) << left << pseudo_registers[i][1]
+    buf << std::setw(c_maxlen) << std::left << pseudo_registers[i][0]
+        << std::setw(2) << " "
+        << std::setw(i_maxlen) << std::left << pseudo_registers[i][1]
         << endl;
   }
 
@@ -613,12 +615,12 @@ void Debugger::getCompletions(const char* in, StringList& list) const
   for(const auto& iter: myFunctions)
   {
     const char* l = iter.first.c_str();
-    if(BSPF_equalsIgnoreCase(l, in))
+    if(BSPF::equalsIgnoreCase(l, in))
       list.push_back(l);
   }
 
   for(int i = 0; pseudo_registers[i][0] != 0; ++i)
-    if(BSPF_equalsIgnoreCase(pseudo_registers[i][0], in))
+    if(BSPF::equalsIgnoreCase(pseudo_registers[i][0], in))
       list.push_back(pseudo_registers[i][0]);
 }
 
