@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: DebuggerParser.cxx 3239 2015-12-29 19:22:46Z stephena $
+// $Id: DebuggerParser.cxx 3317 2016-09-04 23:03:01Z stephena $
 //============================================================================
 
 #include <fstream>
@@ -39,7 +39,12 @@
 #include "Vec.hxx"
 
 #include "Base.hxx"
-using namespace Common;
+using Common::Base;
+using std::hex;
+using std::dec;
+using std::setfill;
+using std::setw;
+using std::right;
 
 #ifdef CHEATCODE_SUPPORT
   #include "Cheat.hxx"
@@ -108,7 +113,7 @@ string DebuggerParser::run(const string& command)
 
   for(int i = 0; i < kNumCommands; ++i)
   {
-    if(BSPF_equalsIgnoreCase(verb, commands[i].cmdString))
+    if(BSPF::equalsIgnoreCase(verb, commands[i].cmdString))
     {
       if(validateArgs(i))
         commands[i].executor(this);
@@ -160,7 +165,7 @@ void DebuggerParser::getCompletions(const char* in, StringList& completions) con
   // cerr << "Attempting to complete \"" << in << "\"" << endl;
   for(int i = 0; i < kNumCommands; ++i)
   {
-    if(BSPF_startsWithIgnoreCase(commands[i].cmdString.c_str(), in))
+    if(BSPF::startsWithIgnoreCase(commands[i].cmdString.c_str(), in))
       completions.push_back(commands[i].cmdString);
   }
 }
@@ -562,9 +567,9 @@ string DebuggerParser::trapStatus(int addr)
   else if(r)
     result += "read";
   else if(w)
-    result += "     write";
+    result += "write";
   else
-    result += "   none   ";
+    result += "none";
 
   // TODO - technically, we should determine if the label is read or write
   const string& l = debugger.cartDebug().getLabel(addr, true);
@@ -580,9 +585,8 @@ string DebuggerParser::trapStatus(int addr)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool DebuggerParser::saveScriptFile(string file)
 {
-  if( file.find_last_of('.') == string::npos ) {
+  if( file.find_last_of('.') == string::npos )
     file += ".stella";
-  }
 
   ofstream out(file);
 
@@ -1288,7 +1292,7 @@ void DebuggerParser::executeRunTo()
     if(pcline >= 0)
     {
       const string& next = list[pcline].disasm;
-      done = (BSPF_findIgnoreCase(next, argStrings[0]) != string::npos);
+      done = (BSPF::findIgnoreCase(next, argStrings[0]) != string::npos);
     }
     // Update the progress bar
     progress.setProgress(count);
@@ -1435,55 +1439,150 @@ void DebuggerParser::executeTrace()
 // "trap"
 void DebuggerParser::executeTrap()
 {
-  uInt32 beg = args[0];
-  uInt32 end = argCount >= 2 ? args[1] : beg;
-  if(beg > end)  BSPF_swap(beg, end);
-
-  for(uInt32 i = beg; i <= end; ++i)
-  {
-    debugger.toggleReadTrap(i);
-    debugger.toggleWriteTrap(i);
-    commandResult << trapStatus(i) << endl;
-  }
+  executeTrapRW(true, true);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 // "trapread"
 void DebuggerParser::executeTrapread()
 {
-  uInt32 beg = args[0];
-  uInt32 end = argCount >= 2 ? args[1] : beg;
-  if(beg > end)  BSPF_swap(beg, end);
-
-  for(uInt32 i = beg; i <= end; ++i)
-  {
-    debugger.toggleReadTrap(i);
-    commandResult << trapStatus(i) << endl;
-  }
+  executeTrapRW(true, false);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 // "trapwrite"
 void DebuggerParser::executeTrapwrite()
+{
+  executeTrapRW(false, true);
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+// wrapper function for trap/trapread/trapwrite commands
+void DebuggerParser::executeTrapRW(bool read, bool write)
 {
   uInt32 beg = args[0];
   uInt32 end = argCount >= 2 ? args[1] : beg;
-  if(beg > end)  BSPF_swap(beg, end);
+  if(beg > end)  std::swap(beg, end);
 
   for(uInt32 i = beg; i <= end; ++i)
   {
-    debugger.toggleWriteTrap(i);
+    if(read)  debugger.toggleReadTrap(i);
+    if(write) debugger.toggleWriteTrap(i);
     commandResult << trapStatus(i) << endl;
   }
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+// "trapm"
+void DebuggerParser::executeTrapM()
+{
+  executeTrapMRW(true, true);
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+// "trapreadm"
+void DebuggerParser::executeTrapreadM()
+{
+  executeTrapMRW(true, false);
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+// "trapwritem"
+void DebuggerParser::executeTrapwriteM()
+{
+  executeTrapMRW(false, true);
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+// wrapper function for trapm/trapreadm/trapwritem commands
+void DebuggerParser::executeTrapMRW(bool read, bool write)
+{
+  uInt32 addr = args[0];
+  uInt32 beg = argCount > 1 ? args[1] : 0;
+  uInt32 end = argCount > 2 ? args[2] : 0xFFFF;
+  if(beg > end)  std::swap(beg, end);
+
+  switch(debugger.cartDebug().addressType(addr))
+  {
+    case CartDebug::ADDR_TIA:
+    {
+      for(uInt32 i = beg; i <= end; ++i)
+      {
+        if((i & 0x1080) == 0x0000 && (i & 0x003F) == addr)
+        {
+          if(read)  debugger.toggleReadTrap(i);
+          if(write) debugger.toggleWriteTrap(i);
+        }
+      }
+      break;
+    }
+    case CartDebug::ADDR_IO:
+    {
+      for(uInt32 i = beg; i <= end; ++i)
+      {
+        if((i & 0x1080) == 0x0080 && (i & 0x0200) != 0x0000 && (i & 0x02FF) == addr)
+        {
+          if(read)  debugger.toggleReadTrap(i);
+          if(write) debugger.toggleWriteTrap(i);
+        }
+      }
+      break;
+    }
+    case CartDebug::ADDR_ZPRAM:
+    {
+      for(uInt32 i = beg; i <= end; ++i)
+      {
+        if((i & 0x1080) == 0x0080 && (i & 0x0200) == 0x0000 && (i & 0x00FF) == addr)
+        {
+          if(read)  debugger.toggleReadTrap(i);
+          if(write) debugger.toggleWriteTrap(i);
+        }
+      }
+      break;
+    }
+    case CartDebug::ADDR_ROM:
+    {
+      // Enforce range?
+      if(argCount > 1)
+      {
+        if(beg < addr) beg = addr & 0xF000;
+        if(end < beg)  beg = end;
+      }
+      else
+      {
+        beg = 0x1000;
+        end = 0xFFFF;
+      }
+
+      // Are we in range?
+      if(!(addr >= beg && addr <= end))
+      {
+        commandResult << "Address " << addr << " is outside range" << endl;
+        return;
+      }
+      for(uInt32 i = beg; i <= end; ++i)
+      {
+        if((i % 0x2000 >= 0x1000) && (i & 0x0FFF) == (addr & 0x0FFF))
+        {
+          if(read)  debugger.toggleReadTrap(i);
+          if(write) debugger.toggleWriteTrap(i);
+        }
+      }
+      break;
+    }
+  }
+
+  commandResult << trapStatus(addr) << " + mirrors from $"
+                << Base::HEX4 << beg << " - $" << end << endl;
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 // "type"
 void DebuggerParser::executeType()
 {
   uInt32 beg = args[0];
   uInt32 end = argCount >= 2 ? args[1] : beg;
-  if(beg > end)  BSPF_swap(beg, end);
+  if(beg > end)  std::swap(beg, end);
 
   for(uInt32 i = beg; i <= end; ++i)
   {
@@ -2123,6 +2222,33 @@ DebuggerParser::Command DebuggerParser::commands[kNumCommands] = {
     std::mem_fn(&DebuggerParser::executeTrapwrite)
   },
 
+  {
+    "trapm",
+    "Trap read/write access to address xx (+mirrors)",
+    true,
+    false,
+    { kARG_WORD, kARG_MULTI_WORD },
+    std::mem_fn(&DebuggerParser::executeTrapM)
+  },
+
+  {
+    "trapreadm",
+    "Trap read access to address xx (+mirrors)",
+    true,
+    false,
+    { kARG_WORD, kARG_MULTI_WORD },
+    std::mem_fn(&DebuggerParser::executeTrapreadM)
+  },
+
+  {
+    "trapwritem",
+    "Trap write access to address xx (+mirrors)",
+    true,
+    false,
+    { kARG_WORD, kARG_MULTI_WORD },
+    std::mem_fn(&DebuggerParser::executeTrapwriteM)
+  },
+
   {
     "type",
     "Show disassembly type for address xx [to yy]",
