@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: DataGridWidget.cxx 3242 2015-12-29 22:39:08Z stephena $
+// $Id: DataGridWidget.cxx 3304 2016-04-03 00:35:00Z stephena $
 //============================================================================
 
 #include "OSystem.hxx"
@@ -238,8 +238,8 @@ void DataGridWidget::setValue(int position, int value, bool changed,
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void DataGridWidget::setRange(int lower, int upper)
 {
-  _lowerBound = BSPF_max(0, lower);
-  _upperBound = BSPF_min(1 << _bits, upper);
+  _lowerBound = std::max(0, lower);
+  _upperBound = std::min(1 << _bits, upper);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
