@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: DebuggerDialog.cxx 3295 2016-03-07 15:36:09Z stephena $
+// $Id: DebuggerDialog.cxx 3304 2016-04-03 00:35:00Z stephena $
 //============================================================================
 
 #include "Widget.hxx"
@@ -453,7 +453,7 @@ void DebuggerDialog::addRomArea()
 GUI::Rect DebuggerDialog::getTiaBounds() const
 {
   // The area showing the TIA image (NTSC and PAL supported, up to 260 lines)
-  GUI::Rect r(0, 0, 320, BSPF_max(260, int(_h * 0.35)));
+  GUI::Rect r(0, 0, 320, std::max(260, int(_h * 0.35)));
   return r;
 }
 
