@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: RiotWidget.cxx 3242 2015-12-29 22:39:08Z stephena $
+// $Id: RiotWidget.cxx 3302 2016-04-02 23:47:46Z stephena $
 //============================================================================
 
 #include "Settings.hxx"
@@ -344,7 +344,7 @@ void RiotWidget::loadConfig()
   const string& cpurandom = instance().settings().getString("cpurandom");
   const char* cpuregs[] = { "S", "A", "X", "Y", "P" };
   for(int i = 0; i < 5; ++i)
-    myRandomizeCPU[i]->setState(BSPF_containsIgnoreCase(cpurandom, cpuregs[i]));
+    myRandomizeCPU[i]->setState(BSPF::containsIgnoreCase(cpurandom, cpuregs[i]));
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
