@@ -14,17 +14,15 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: Cart.cxx 3294 2016-03-05 18:35:25Z stephena $
+// $Id: Cart.cxx 3316 2016-08-24 23:57:07Z stephena $
 //============================================================================
 
-#include <cstring>
-#include <sstream>
-
 #include "bspf.hxx"
 #include "Cart.hxx"
 #include "Cart0840.hxx"
 #include "Cart2K.hxx"
 #include "Cart3E.hxx"
+#include "Cart3EPlus.hxx"
 #include "Cart3F.hxx"
 #include "Cart4A50.hxx"
 #include "Cart4K.hxx"
@@ -190,6 +188,8 @@ unique_ptr<Cartridge> Cartridge::create(const BytePtr& img, uInt32 size,
     cartridge = make_ptr<Cartridge2K>(image, size, settings);
   else if(type == "3E")
     cartridge = make_ptr<Cartridge3E>(image, size, settings);
+  else if(type == "3E+")
+    cartridge = make_ptr<Cartridge3EPlus>(image, size, settings);
   else if(type == "3F")
     cartridge = make_ptr<Cartridge3F>(image, size, settings);
   else if(type == "4A50")
@@ -361,6 +361,16 @@ void Cartridge::createCodeAccessBase(uInt32 size)
 #endif
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void Cartridge::initializeRAM(uInt8* arr, uInt32 size, uInt8 val) const
+{
+  if(mySettings.getBool("ramrandom"))
+    for(uInt32 i = 0; i < size; ++i)
+      arr[i] = mySystem->randGenerator().next();
+  else
+    memset(arr, val, size);
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 string Cartridge::autodetectType(const uInt8* image, uInt32 size)
 {
@@ -527,6 +537,8 @@ string Cartridge::autodetectType(const uInt8* image, uInt32 size)
   // Variable sized ROM formats are independent of image size and come last
   if(isProbablyDASH(image, size))
     type = "DASH";
+  else if(isProbably3EPlus(image, size))
+    type = "3E+";
   else if(isProbablyMDM(image, size))
     type = "MDM";
 
@@ -647,6 +659,14 @@ bool Cartridge::isProbably3E(const uInt8* image, uInt32 size)
   return searchForBytes(image, size, signature, 4, 1);
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+bool Cartridge::isProbably3EPlus(const uInt8* image, uInt32 size)
+{
+  // 3E+ cart is identified key 'TJ3E' in the ROM
+  uInt8 signature[] = { 'T', 'J', '3', 'E' };
+  return searchForBytes(image, size, signature, 4, 1);
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool Cartridge::isProbably3F(const uInt8* image, uInt32 size)
 {
@@ -974,6 +994,7 @@ Cartridge::BankswitchType Cartridge::ourBSList[ourNumBSTypes] = {
   { "128IN1",   "128IN1 Multicart (256/512K)"   },
   { "2K",       "2K (64-2048 bytes Atari)"      },
   { "3E",       "3E (32K Tigervision)"          },
+  { "3E+",      "3E+ (TJ modified DASH)"        },
   { "3F",       "3F (512K Tigervision)"         },
   { "4A50",     "4A50 (64K 4A50 + ram)"         },
   { "4K",       "4K (4K Atari)"                 },
