@@ -14,11 +14,9 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: CartAR.cxx 3258 2016-01-23 22:56:16Z stephena $
+// $Id: CartAR.cxx 3316 2016-08-24 23:57:07Z stephena $
 //============================================================================
 
-#include <cstring>
-
 #include "M6502.hxx"
 #include "System.hxx"
 #include "CartAR.hxx"
@@ -27,8 +25,7 @@
 CartridgeAR::CartridgeAR(const uInt8* image, uInt32 size,
                          const Settings& settings)
   : Cartridge(settings),
-    mySize(BSPF_max(size, 8448u)),
-    myLoadImages(nullptr),
+    mySize(std::max(size, 8448u)),
     myWriteEnabled(false),
     myPower(true),
     myPowerRomCycle(0),
@@ -60,10 +57,7 @@ void CartridgeAR::reset()
 {
   // Initialize RAM
 #if 0  // TODO - figure out actual behaviour of the real cart
-  if(mySettings.getBool("ramrandom"))
-    for(uInt32 i = 0; i < 6 * 1024; ++i)
-      myImage[i] = mySystem->randGenerator().next();
-  else
+  initializeRAM(myImage, 6*1024);
 #endif
     memset(myImage, 0, 6 * 1024);
 
