@@ -14,11 +14,9 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: CartDPCPlus.cxx 3258 2016-01-23 22:56:16Z stephena $
+// $Id: CartDPCPlus.cxx 3316 2016-08-24 23:57:07Z stephena $
 //============================================================================
 
-#include <cstring>
-
 #ifdef DEBUGGER_SUPPORT
   #include "Debugger.hxx"
 #endif
@@ -30,7 +28,6 @@
 CartridgeDPCPlus::CartridgeDPCPlus(const uInt8* image, uInt32 size,
                                    const Settings& settings)
   : Cartridge(settings),
-    myImage(nullptr),
     myFastFetch(false),
     myLDAimmediate(false),
     myParameterPointer(0),
@@ -40,7 +37,7 @@ CartridgeDPCPlus::CartridgeDPCPlus(const uInt8* image, uInt32 size,
 {
   // Store image, making sure it's at least 29KB
   uInt32 minsize = 4096 * 6 + 4096 + 1024 + 255;
-  mySize = BSPF_max(minsize, size);
+  mySize = std::max(minsize, size);
   myImage = make_ptr<uInt8[]>(mySize);
   memcpy(myImage.get(), image, size);
   createCodeAccessBase(4096 * 6);
