@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: Console.cxx 3239 2015-12-29 19:22:46Z stephena $
+// $Id: Console.cxx 3310 2016-08-18 18:44:57Z stephena $
 //============================================================================
 
 #include <cassert>
@@ -560,7 +560,7 @@ void Console::setTIAProperties()
     myConsoleInfo.InitialFrameRate = "50";
 
     // PAL ROMs normally need at least 250 lines
-    height = BSPF_max(height, 250u);
+    height = std::max(height, 250u);
   }
 
   // Make sure these values fit within the bounds of the desktop
@@ -569,7 +569,7 @@ void Console::setTIAProperties()
   if(height > dheight)
   {
     ystart += height - dheight;
-    ystart = BSPF_min(ystart, 64u);
+    ystart = std::min(ystart, 64u);
     height = dheight;
   }
   myTIA->setYStart(ystart);
@@ -619,7 +619,7 @@ void Console::setControllers(const string& rommd5)
   {
     leftC = make_ptr<Keyboard>(Controller::Left, myEvent, *mySystem);
   }
-  else if(BSPF_startsWithIgnoreCase(left, "PADDLES"))
+  else if(BSPF::startsWithIgnoreCase(left, "PADDLES"))
   {
     bool swapAxis = false, swapDir = false;
     if(left == "PADDLES_IAXIS")
@@ -672,7 +672,7 @@ void Console::setControllers(const string& rommd5)
   {
     rightC = make_ptr<Keyboard>(Controller::Right, myEvent, *mySystem);
   }
-  else if(BSPF_startsWithIgnoreCase(right, "PADDLES"))
+  else if(BSPF::startsWithIgnoreCase(right, "PADDLES"))
   {
     bool swapAxis = false, swapDir = false;
     if(right == "PADDLES_IAXIS")
@@ -746,16 +746,16 @@ void Console::setControllers(const string& rommd5)
 void Console::loadUserPalette()
 {
   const string& palette = myOSystem.paletteFile();
-  ifstream in(palette, ios::binary);
+  ifstream in(palette, std::ios::binary);
   if(!in)
     return;
 
   // Make sure the contains enough data for the NTSC, PAL and SECAM palettes
   // This means 128 colours each for NTSC and PAL, at 3 bytes per pixel
   // and 8 colours for SECAM at 3 bytes per pixel
-  in.seekg(0, ios::end);
-  streampos length = in.tellg();
-  in.seekg(0, ios::beg);
+  in.seekg(0, std::ios::end);
+  std::streampos length = in.tellg();
+  in.seekg(0, std::ios::beg);
   if(length < 128 * 3 * 2 + 8 * 3)
   {
     cerr << "ERROR: invalid palette file " << palette << endl;
