@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: EventHandler.cxx 3287 2016-02-24 20:49:49Z stephena $
+// $Id: EventHandler.cxx 3308 2016-05-24 16:55:45Z stephena $
 //============================================================================
 
 #include <sstream>
@@ -1797,7 +1797,8 @@ void EventHandler::takeSnapshot(uInt32 number)
   if(number > 0)
   {
     ostringstream buf;
-    buf << sspath << "_" << hex << setw(8) << setfill('0') << number << ".png";
+    buf << sspath << "_" << std::hex << std::setw(8) << std::setfill('0')
+        << number << ".png";
     filename = buf.str();
   }
   else if(!myOSystem.settings().getBool("sssingle"))
@@ -1827,7 +1828,7 @@ void EventHandler::takeSnapshot(uInt32 number)
   VariantList comments;
   ostringstream version;
   version << "Stella " << STELLA_VERSION << " (Build " << STELLA_BUILD << ") ["
-          << BSPF_ARCH << "]";
+          << BSPF::ARCH << "]";
   VarList::push_back(comments, "Software", version.str());
   VarList::push_back(comments, "ROM Name", myOSystem.console().properties().get(Cartridge_Name));
   VarList::push_back(comments, "ROM MD5", myOSystem.console().properties().get(Cartridge_MD5));
@@ -1879,9 +1880,9 @@ void EventHandler::setMouseControllerMode(const string& enable)
   if(myOSystem.hasConsole())
   {
     bool usemouse = false;
-    if(BSPF_equalsIgnoreCase(enable, "always"))
+    if(BSPF::equalsIgnoreCase(enable, "always"))
       usemouse = true;
-    else if(BSPF_equalsIgnoreCase(enable, "never"))
+    else if(BSPF::equalsIgnoreCase(enable, "never"))
       usemouse = false;
     else  // 'analog'
     {
