@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: OSystem.cxx 3249 2016-01-18 16:03:22Z stephena $
+// $Id: OSystem.cxx 3308 2016-05-24 16:55:45Z stephena $
 //============================================================================
 
 #include <cassert>
@@ -87,7 +87,7 @@ OSystem::OSystem()
 
   info << "Build " << STELLA_BUILD << ", using SDL " << int(ver.major)
        << "." << int(ver.minor) << "."<< int(ver.patch)
-       << " [" << BSPF_ARCH << "]";
+       << " [" << BSPF::ARCH << "]";
   myBuildInfo = info.str();
 
   mySettings = MediaFactory::createSettings(*this);
@@ -369,27 +369,27 @@ string OSystem::createConsole(const FilesystemNode& rom, const string& md5sum,
       myEventHandler->handleEvent(Event::ConsoleSelect, 1);
 
     const string& holdjoy0 = mySettings->getString("holdjoy0");
-    if(BSPF_containsIgnoreCase(holdjoy0, "U"))
+    if(BSPF::containsIgnoreCase(holdjoy0, "U"))
       myEventHandler->handleEvent(Event::JoystickZeroUp, 1);
-    if(BSPF_containsIgnoreCase(holdjoy0, "D"))
+    if(BSPF::containsIgnoreCase(holdjoy0, "D"))
       myEventHandler->handleEvent(Event::JoystickZeroDown, 1);
-    if(BSPF_containsIgnoreCase(holdjoy0, "L"))
+    if(BSPF::containsIgnoreCase(holdjoy0, "L"))
       myEventHandler->handleEvent(Event::JoystickZeroLeft, 1);
-    if(BSPF_containsIgnoreCase(holdjoy0, "R"))
+    if(BSPF::containsIgnoreCase(holdjoy0, "R"))
       myEventHandler->handleEvent(Event::JoystickZeroRight, 1);
-    if(BSPF_containsIgnoreCase(holdjoy0, "F"))
+    if(BSPF::containsIgnoreCase(holdjoy0, "F"))
       myEventHandler->handleEvent(Event::JoystickZeroFire, 1);
 
     const string& holdjoy1 = mySettings->getString("holdjoy1");
-    if(BSPF_containsIgnoreCase(holdjoy1, "U"))
+    if(BSPF::containsIgnoreCase(holdjoy1, "U"))
       myEventHandler->handleEvent(Event::JoystickOneUp, 1);
-    if(BSPF_containsIgnoreCase(holdjoy1, "D"))
+    if(BSPF::containsIgnoreCase(holdjoy1, "D"))
       myEventHandler->handleEvent(Event::JoystickOneDown, 1);
-    if(BSPF_containsIgnoreCase(holdjoy1, "L"))
+    if(BSPF::containsIgnoreCase(holdjoy1, "L"))
       myEventHandler->handleEvent(Event::JoystickOneLeft, 1);
-    if(BSPF_containsIgnoreCase(holdjoy1, "R"))
+    if(BSPF::containsIgnoreCase(holdjoy1, "R"))
       myEventHandler->handleEvent(Event::JoystickOneRight, 1);
-    if(BSPF_containsIgnoreCase(holdjoy1, "F"))
+    if(BSPF::containsIgnoreCase(holdjoy1, "F"))
       myEventHandler->handleEvent(Event::JoystickOneFire, 1);
   #ifdef DEBUGGER_SUPPORT
     if(mySettings->getBool("debug"))
@@ -465,13 +465,13 @@ void OSystem::logMessage(const string& message, uInt8 level)
 {
   if(level == 0)
   {
-    cout << message << endl << flush;
+    cout << message << endl << std::flush;
     myLogMessages += message + "\n";
   }
   else if(level <= uInt8(mySettings->getInt("loglevel")))
   {
     if(mySettings->getBool("logtoconsole"))
-      cout << message << endl << flush;
+      cout << message << endl << std::flush;
     myLogMessages += message + "\n";
   }
 }
