@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: Settings.cxx 3277 2016-02-12 14:28:30Z stephena $
+// $Id: Settings.cxx 3308 2016-05-24 16:55:45Z stephena $
 //============================================================================
 
 #include <cassert>
@@ -472,7 +472,7 @@ void Settings::usage() const
     << "   -pp          <arg>          Sets the 'Display.Phosphor' property\n"
     << "   -ppblend     <arg>          Sets the 'Display.PPBlend' property\n"
   #endif
-    << endl << flush;
+    << endl << std::flush;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
