@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: Thumbulator.cxx 3290 2016-02-27 19:58:20Z stephena $
+// $Id: Thumbulator.cxx 3308 2016-05-24 16:55:45Z stephena $
 //============================================================================
 
 //============================================================================
@@ -29,7 +29,7 @@
 #include "bspf.hxx"
 #include "Base.hxx"
 #include "Thumbulator.hxx"
-using namespace Common;
+using Common::Base;
 
 // Uncomment the following to enable specific functionality
 // WARNING!!! This slows the runtime to a crawl
