@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: Dialog.cxx 3254 2016-01-23 18:16:09Z stephena $
+// $Id: Dialog.cxx 3304 2016-04-03 00:35:00Z stephena $
 //
 //   Based on code from ScummVM - Scumm Interpreter
 //   Copyright (C) 2002-2004 The ScummVM project
@@ -648,9 +648,9 @@ void Dialog::addOKCancelBGroup(WidgetArray& wid, const GUI::Font& font,
                                const string& okText, const string& cancelText)
 {
 
-  int buttonWidth  = BSPF_max(font.getStringWidth("Cancel"),
-                      BSPF_max(font.getStringWidth(okText),
-                      font.getStringWidth(okText))) + 15;
+  int buttonWidth = std::max(font.getStringWidth("Cancel"),
+                    std::max(font.getStringWidth(okText),
+                    font.getStringWidth(okText))) + 15;
   int buttonHeight = font.getLineHeight() + 4;
   ButtonWidget* b;
 #ifndef BSPF_MAC_OSX
