@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: GameInfoDialog.cxx 3250 2016-01-18 18:33:45Z stephena $
+// $Id: GameInfoDialog.cxx 3302 2016-04-02 23:47:46Z stephena $
 //============================================================================
 
 #include "Cart.hxx"
@@ -436,7 +436,7 @@ void GameInfoDialog::loadView()
   istringstream m_axis(myGameProperties.get(Controller_MouseAxis));
   string m_control, m_range;
   m_axis >> m_control;
-  bool autoAxis = BSPF_equalsIgnoreCase(m_control, "AUTO");
+  bool autoAxis = BSPF::equalsIgnoreCase(m_control, "AUTO");
   if(autoAxis)
   {
     myMouseControl->setSelectedIndex(0);
