@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: LauncherDialog.cxx 3245 2015-12-30 20:26:56Z stephena $
+// $Id: LauncherDialog.cxx 3304 2016-04-03 00:35:00Z stephena $
 //============================================================================
 
 #include <sstream>
@@ -82,7 +82,7 @@ LauncherDialog::LauncherDialog(OSystem& osystem, DialogContainer& parent,
   // It has to fit between both labels
   if(w >= 640)
   {
-    int fwidth = BSPF_min(15 * fontWidth, xpos - 20 - lwidth);
+    int fwidth = std::min(15 * fontWidth, xpos - 20 - lwidth);
     xpos -= fwidth + 5;
     myPattern = new EditTextWidget(this, font, xpos, ypos,
                                    fwidth, fontHeight, "");
