@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: UIDialog.cxx 3243 2015-12-29 23:45:21Z stephena $
+// $Id: UIDialog.cxx 3304 2016-04-03 00:35:00Z stephena $
 //============================================================================
 
 #include <sstream>
@@ -134,7 +134,7 @@ UIDialog::UIDialog(OSystem& osystem, DialogContainer& parent,
   // Add message concerning usage
   xpos = vBorder; ypos += 1*(lineHeight + 4);
   lwidth = ifont.getStringWidth("(*) Changes require application restart");
-  new StaticTextWidget(myTab, ifont, xpos, ypos, BSPF_min(lwidth, _w-20), fontHeight,
+  new StaticTextWidget(myTab, ifont, xpos, ypos, std::min(lwidth, _w-20), fontHeight,
                        "(*) Changes require application restart",
                        kTextAlignLeft);
 
@@ -284,7 +284,7 @@ UIDialog::UIDialog(OSystem& osystem, DialogContainer& parent,
   // Add message concerning usage
   xpos = vBorder; ypos += 1*(lineHeight + 4);
   lwidth = ifont.getStringWidth("(*) Requires application restart");
-  new StaticTextWidget(myTab, ifont, xpos, ypos, BSPF_min(lwidth, _w-20), fontHeight,
+  new StaticTextWidget(myTab, ifont, xpos, ypos, std::min(lwidth, _w-20), fontHeight,
                        "(*) Requires application restart",
                        kTextAlignLeft);
 
@@ -310,10 +310,10 @@ void UIDialog::loadConfig()
   const GUI::Size& ls = instance().settings().getSize("launcherres");
   uInt32 w = ls.w, h = ls.h;
 
-  w = BSPF_max(w, uInt32(FrameBuffer::kFBMinW));
-  h = BSPF_max(h, uInt32(FrameBuffer::kFBMinH));
-  w = BSPF_min(w, instance().frameBuffer().desktopSize().w);
-  h = BSPF_min(h, instance().frameBuffer().desktopSize().h);
+  w = std::max(w, uInt32(FrameBuffer::kFBMinW));
+  h = std::max(h, uInt32(FrameBuffer::kFBMinH));
+  w = std::min(w, instance().frameBuffer().desktopSize().w);
+  h = std::min(h, instance().frameBuffer().desktopSize().h);
 
   myLauncherWidthSlider->setValue(w);
   myLauncherWidthLabel->setValue(w);
@@ -336,10 +336,10 @@ void UIDialog::loadConfig()
   // Debugger size
   const GUI::Size& ds = instance().settings().getSize("dbg.res");
   w = ds.w, h = ds.h;
-  w = BSPF_max(w, uInt32(DebuggerDialog::kSmallFontMinW));
-  h = BSPF_max(h, uInt32(DebuggerDialog::kSmallFontMinH));
-  w = BSPF_min(w, ds.w);
-  h = BSPF_min(h, ds.h);
+  w = std::max(w, uInt32(DebuggerDialog::kSmallFontMinW));
+  h = std::max(h, uInt32(DebuggerDialog::kSmallFontMinH));
+  w = std::min(w, ds.w);
+  h = std::min(h, ds.h);
 
   myDebuggerWidthSlider->setValue(w);
   myDebuggerWidthLabel->setValue(w);
@@ -417,8 +417,8 @@ void UIDialog::setDefaults()
   {
     case 0:  // Launcher options
     {
-      uInt32 w = BSPF_min(instance().frameBuffer().desktopSize().w, 1000u);
-      uInt32 h = BSPF_min(instance().frameBuffer().desktopSize().h, 600u);
+      uInt32 w = std::min(instance().frameBuffer().desktopSize().w, 1000u);
+      uInt32 h = std::min(instance().frameBuffer().desktopSize().h, 600u);
       myLauncherWidthSlider->setValue(w);
       myLauncherWidthLabel->setValue(w);
       myLauncherHeightSlider->setValue(h);
@@ -432,8 +432,8 @@ void UIDialog::setDefaults()
     case 1:  // Debugger options
     {
 #ifdef DEBUGGER_SUPPORT
-      uInt32 w = BSPF_min(instance().frameBuffer().desktopSize().w, uInt32(DebuggerDialog::kMediumFontMinW));
-      uInt32 h = BSPF_min(instance().frameBuffer().desktopSize().h, uInt32(DebuggerDialog::kMediumFontMinH));
+      uInt32 w = std::min(instance().frameBuffer().desktopSize().w, uInt32(DebuggerDialog::kMediumFontMinW));
+      uInt32 h = std::min(instance().frameBuffer().desktopSize().h, uInt32(DebuggerDialog::kMediumFontMinH));
       myDebuggerWidthSlider->setValue(w);
       myDebuggerWidthLabel->setValue(w);
       myDebuggerHeightSlider->setValue(h);
