@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: VideoDialog.cxx 3279 2016-02-13 01:21:28Z stephena $
+// $Id: VideoDialog.cxx 3304 2016-04-03 00:35:00Z stephena $
 //============================================================================
 
 #include <sstream>
@@ -53,8 +53,8 @@ VideoDialog::VideoDialog(OSystem& osystem, DialogContainer& parent,
   VariantList items;
 
   // Set real dimensions
-  _w = BSPF_min(52 * fontWidth + 10, max_w);
-  _h = BSPF_min(14 * (lineHeight + 4) + 10, max_h);
+  _w = std::min(52 * fontWidth + 10, max_w);
+  _h = std::min(14 * (lineHeight + 4) + 10, max_h);
 
   // The tab widget
   xpos = ypos = 5;
