@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: Widget.cxx 3239 2015-12-29 19:22:46Z stephena $
+// $Id: Widget.cxx 3304 2016-04-03 00:35:00Z stephena $
 //
 //   Based on code from ScummVM - Scumm Interpreter
 //   Copyright (C) 2002-2004 The ScummVM project
@@ -312,7 +312,7 @@ StaticTextWidget::StaticTextWidget(GuiObject* boss, const GUI::Font& font,
 void StaticTextWidget::setValue(int value)
 {
   char buf[256];
-  BSPF_snprintf(buf, 255, "%d", value);
+  std::snprintf(buf, 255, "%d", value);
   _label = buf;
 
   setDirty();
@@ -701,7 +701,7 @@ int SliderWidget::valueToPos(int value)
 {
   if(value < _valueMin)      value = _valueMin;
   else if(value > _valueMax) value = _valueMax;
-  int range = BSPF_max(_valueMax - _valueMin, 1);  // don't divide by zero
+  int range = std::max(_valueMax - _valueMin, 1);  // don't divide by zero
   
   return ((_w - _labelWidth - 4) * (value - _valueMin) / range);
 }
