@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: FSNodePOSIX.cxx 3294 2016-03-05 18:35:25Z stephena $
+// $Id: FSNodePOSIX.cxx 3302 2016-04-02 23:47:46Z stephena $
 //============================================================================
 
 #include "FSNodePOSIX.hxx"
@@ -81,7 +81,7 @@ string FilesystemNodePOSIX::getShortPath() const
 {
   // If the path starts with the home directory, replace it with '~'
   const char* home = getenv("HOME");
-  if(home != NULL && BSPF_startsWithIgnoreCase(_path, home))
+  if(home != NULL && BSPF::startsWithIgnoreCase(_path, home))
   {
     string path = "~";
     const char* offset = _path.c_str() + strlen(home);
